summaryrefslogtreecommitdiffstats
path: root/Source/cmGlobalNinjaGenerator.cxx
diff options
context:
space:
mode:
authorRolf Eike Beer <eike@sf-mail.de>2013-06-03 17:42:18 (GMT)
committerBrad King <brad.king@kitware.com>2013-06-03 17:43:52 (GMT)
commite4e09212c58995a6cfde7d101bc02fce0f7829be (patch)
tree219aa9a80e2c182d3be38d3cccf8f3809c585720 /Source/cmGlobalNinjaGenerator.cxx
parentc9b75dcd734e2dd09eadbd9b16a6497bae95941c (diff)
parenta4d8c64d10105fd4448ffde6a5d2fb74c1bb4f57 (diff)
downloadCMake-e4e09212c58995a6cfde7d101bc02fce0f7829be.zip
CMake-e4e09212c58995a6cfde7d101bc02fce0f7829be.tar.gz
CMake-e4e09212c58995a6cfde7d101bc02fce0f7829be.tar.bz2
Merge branch 'master' into escape-regex-specials-in-path
Resolve conflicts in Tests/CTestTestMemcheck/CMakeLists.txt by combining changes from both sides.
Diffstat (limited to 'Source/cmGlobalNinjaGenerator.cxx')
-rw-r--r--Source/cmGlobalNinjaGenerator.cxx4
1 files changed, 3 insertions, 1 deletions
diff --git a/Source/cmGlobalNinjaGenerator.cxx b/Source/cmGlobalNinjaGenerator.cxx
index fa277b1..fff972e 100644
--- a/Source/cmGlobalNinjaGenerator.cxx
+++ b/Source/cmGlobalNinjaGenerator.cxx
@@ -523,14 +523,16 @@ bool cmGlobalNinjaGenerator::UsingMinGW = false;
std::string cmGlobalNinjaGenerator
::GenerateBuildCommand(const char* makeProgram,
const char* projectName,
+ const char* projectDir,
const char* additionalOptions,
const char* targetName,
const char* config,
bool ignoreErrors,
bool fast)
{
// Project name and config are not used yet.
(void)projectName;
+ (void)projectDir;
(void)config;
// Ninja does not have -i equivalent option yet.
(void)ignoreErrors;
@@ -523,14 +523,16 @@ bool cmGlobalNinjaGenerator::UsingMinGW = false;
bool fast)
{
- // Project name and config are not used yet.
+ // Project name & dir and config are not used yet.
(void)projectName;